#
# spec file for package ghc-streaming-bytestring
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name streaming-bytestring
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.2.1
Release:        bp156.4.4
Summary:        Fast, effectful byte streams
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-mmorph-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-resourcet-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-streaming-devel
BuildRequires:  ghc-transformers-base-devel
BuildRequires:  ghc-transformers-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-smallcheck-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-smallcheck-devel
%endif

%description
This library enables fast and safe streaming of byte data, in either 'Word8' or
'Char' form. It is a core addition to the <https://github.com/haskell-streaming
streaming ecosystem> and avoids the usual pitfalls of combinbing lazy
'ByteString's with lazy 'IO'.

We follow the philosophy shared by 'streaming' that "the best API is the one
you already know". Thus this library mirrors the API of the 'bytestring'
library as closely as possible.

See the module documentation and the README for more information.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%autosetup -n %{pkg_name}-%{version}
cabal-tweak-dep-ver mmorph '<1.2' '< 2'

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Tue Feb 15 2022 Peter Simons <psimons@suse.com>
- Update copyright header in the spec file.
* Fri Feb 11 2022 Peter Simons <psimons@suse.com>
- Update jailbreak for mmorph.
* Tue Aug 17 2021 Ondřej Súkup <mimi.vx@gmail.com>
- relax constraints on mmorph
* Thu Jun 24 2021 psimons@suse.com
- Update streaming-bytestring to version 0.2.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/streaming-bytestring-0.2.1/src/CHANGELOG.md
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Sun Nov  8 2020 psimons@suse.com
- Add streaming-bytestring at version 0.2.0.
